# Roles in the `auxi` Project
There are currently two roles in the `auxi` project, namely maintainer and contributor. They are explained below.


## Maintainer

### Responsibilities
Maintainers have the following responsibilities:
* Put procedures and standards in place for the project
* Evaluate and approve issues
* Create branches for issues, bugfixes and releases
* Evaluate and approve pull requests
* Create new releases

### Access Rights
Maintainers have full access to the central `auxi` repository, and can therefore do anything.


## Contributor

### Responsibilities
Contributors have the following responsibilities:
* Adhere to project standards and procedures
* Create and document issues to report bugs and propose enhancements
* Create, modify and improve code, tests and documentation for new features, bugfixes and releases
* Submit pull requests to have their contributions integrated into the central repository

### Access Rights
Contributors have read access to the central `auxi` repository. They therefore cannot make changes or additions to files in the central repository directly. Their contributions flow via pull requests from their fork repository to the central repository.
